<?php

namespace progress\models;

/**
 * Description of Helper
 *
 * @author Artem Yuriev art3mk4@gmail.com Dec 4, 2018 11:24:44 AM
 */
class Helper
{

    /**
     * wp_parse_args
     * 
     * @param type $args
     * @param type $defaults
     * @return type
     */
    public static function wp_parse_args($args, $defaults = '')
    {
        if (is_object($args)) {
            $r = get_object_vars($args);
        } elseif (is_array($args)) {
            $r = &$args;
        } else {
            self::wp_parse_str($args, $r);
        }

	if (is_array($defaults)) {
            return array_merge($defaults, $r);
        }

	return $r;
    }

    /**
     * wp_parse_str
     * 
     * @param type $string
     * @param type $array
     */
    public static function wp_parse_str($string, &$array)
    {
        parse_str($string, $array);
	if (get_magic_quotes_gpc()) {
            $array = stripslashes_deep($array);
        }
    }

    /**
     * merge_defaults
     * 
     * @param type $args
     * @param type $defaults
     * @param type $maxLevel
     * @param type $level
     * @return type
     */
    public static function merge_defaults($args, $defaults, $maxLevel = 2, $level = 1)
    {
        if (empty($args)
            || !is_array($args)
        ) {
            return $defaults;
        }

        foreach ($defaults as $key => $value) {
            if (!isset($args[$key])) {
                $args[$key] = $defaults[$key];
                continue;
            }

            if (is_array($value) && $level < $maxLevel) {
                $args[$key] = self::merge_defaults($args[$key], $defaults[$key], $maxLevel, $level++);
                continue;
            }
        }

        return $args;
    }

    /**
     * strip_shortcodes
     * 
     * @global type $shortcode_tags
     * @param type $content
     * @return type
     */
    public static function strip_shortcodes($content)
    {
        global $shortcode_tags;
	if (false === strpos($content, '[')) {
            return $content;
	}

	if (empty($shortcode_tags) || !is_array($shortcode_tags)) {
            return $content;
        }

	// Find all registered tag names in $content.
	preg_match_all('@\[([^<>&/\[\]\x00-\x20=]++)@', $content, $matches);
	$tagnames = array_intersect(array_keys($shortcode_tags), $matches[1]);
	if (empty($tagnames)) {
            return $content;
	}

	$content = do_shortcodes_in_html_tags($content, true, $tagnames);
	$pattern = get_shortcode_regex($tagnames);
	$content = preg_replace_callback("/$pattern/", 'strip_shortcode_tag', $content);

	// Always restore square braces so we don't break things like <!--[if IE ]>
	$content = unescape_invalid_shortcodes($content);
	return $content;
    }

    /**
     * ads_get_list_currency
     * 
     * @return type
     */
    public static function ads_get_list_currency()
    {
	$foo = [
            'AED' => [
                'flag'   => 'AE',
                'symbol' => 'AED ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'United Arab Emirates Dirham (AED)', 'ads' )
            ],
            'ALL' => [
                'flag'   => 'AL',
                'symbol' => 'Lek',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Albanian Lek (ALL)', 'ads' )
            ],
            'AUD' => [
                'flag'   => 'AU',
                'symbol' => 'AUD ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Australian Dollar (AUD)', 'ads' )
            ],
            'BDT' => [
                'flag'   => 'BD',
                'symbol' => ' ৳',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Bangladeshi Taka (BDT)', 'ads' )
            ],
            'BRL' => [
                'flag'   => 'BR',
                'symbol' => 'R$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Brazilian Real (R$)', 'ads' )
            ],
            'CAD' => [
                'flag'   => 'CA',
                'symbol' => 'CA$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Canadian Dollar (CA$)', 'ads' )
            ],
            'CHF' => [
                'flag'   => 'CH',
                'symbol' => 'CHF ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Swiss Franc (CHF)', 'ads' )
            ],
            'CLP' => [
                'flag'   => 'CL',
                'symbol' => 'CLP $ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Chilean Peso (CLP $)', 'ads' )
            ],
            'CNY' => [
                'flag'   => 'CN',
                'symbol' => ' ¥',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Chinese Yuan (CN¥)', 'ads' )
            ],
            'COP' => [
                'flag'   => 'CO',
                'symbol' => ' COP',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Colombian Peso (COP)', 'ads' )
            ],
            'CZK' => [
                'flag'   => 'CZ',
                'symbol' => ' Kč',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Czech Republic Koruna (CZK)', 'ads' )
            ],
            'XAF' => [
                'flag'   => 'empty',
                'symbol' => ' XAF',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Central African CFA franc (XAF)', 'ads' )
            ],
            'DZD' => [
                'flag'   => 'DZ',
                'symbol' => 'DZD ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Algerian Dinars (DZD)', 'ads' )
            ],
            'EUR' => [
                'flag'   => 'EU',
                'symbol' => ' €',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Euro (€)', 'ads' )
            ],
            'GBP' => [
                'flag'   => 'GB',
                'symbol' => '£ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'British Pound Sterling (£)', 'ads' )
            ],
            'HRK' => [
                'flag'   => 'HR',
                'symbol' => ' HRK',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Croatian Kuna (HRK)', 'ads' )
            ],
            'HUF' => [
                'flag'   => 'HU',
                'symbol' => ' HUF',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Hungarian Forint (HUF)', 'ads' )
            ],
            'IDR' => [
                'flag'   => 'ID',
                'symbol' => 'Rp ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Indonesian Rupiah (IDR)', 'ads' )
            ],
            'ILS' => [
                'flag'   => 'IL',
                'symbol' => 'ILS ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Israeli Shekel (ILS)', 'ads' )
            ],
            'INR' => [
                'flag'   => 'IN',
                'symbol' => '₹ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Indian Rupee (Rs.)', 'ads' )
            ],
            'KRW' => [
                'flag'   => 'KR',
                'symbol' => '₩ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'South Korean Won (₩)', 'ads' )
            ],
            'MAD' => [
                'flag'   => 'MA',
                'symbol' => 'MAD ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Moroccan dirham (MAD)', 'ads' )
            ],
            'MYR' => [
                'flag'   => 'MY',
                'symbol' => 'RM ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Malaysian Ringgit (MYR)', 'ads' )
            ],
            'NGN' => [
                'flag'   => 'NG',
                'symbol' => '₦ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Nigerian Naira (₦)', 'ads' )
            ],
            'NOK' => [
                'flag'   => 'NO',
                'symbol' => ' kr',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Norwegian Krone (NOK)', 'ads' )
            ],
            'NZD' => [
                'flag'   => 'NZ',
                'symbol' => 'NZ$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'New Zealand Dollar (NZ$)', 'ads' )
            ],
            'OMR' => [
                'flag'   => 'OM',
                'symbol' => ' OMR',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Omani Rial (OMR)', 'ads' )
            ],
            'PHP' => [
                'flag'   => 'PH',
                'symbol' => '₱ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Philippine Peso (PHP)', 'ads' )
            ],
            'PKR' => [
                'flag'   => 'PK',
                'symbol' => '₨.',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Pakistan Rupee (PKR)', 'ads' )
            ],
            'PLN' => [
                'flag'   => 'PL',
                'symbol' => ' zł',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Polish Zloty (PLN)', 'ads' )
            ],
            'RUB' => [
                'flag'   => 'RU',
                'symbol' => ' руб.',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Russian Ruble (RUB)', 'ads' )
            ],
            'SAR' => [
                'flag'   => 'SA',
                'symbol' => ' SR',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Saudi Riyal (SAR)', 'ads' )
            ],
            'SEK' => [
                'flag'   => 'SE',
                'symbol' => ' SEK',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Swedish Krona (SEK)', 'ads' )
            ],
            'SGD' => [
                'flag'   => 'SG',
                'symbol' => ' SGD',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Singapore Dollar (SGD)', 'ads' )
            ],
            'LKR' => [
                'flag'   => 'LK',
                'symbol' => ' LKR',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Sri Lankan Rupee (LKR)', 'ads' )
            ],
            'THB' => [
                'flag'   => 'TH',
                'symbol' => '฿ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Thai Baht (฿)', 'ads' )
            ],
            'TND' => [
                'flag'   => 'TN',
                'symbol' => 'TND ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Tunisian Dinars (TND)', 'ads' )
            ],
            'QAR' => [
                'flag'   => 'QA',
                'symbol' => 'QAR ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Qatari Riyals (QAR)', 'ads' )
            ],
            'UAH' => [
                'flag'   => 'UA',
                'symbol' => ' грн.',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Ukrainian Hryvnia (грн.)', 'ads' )
            ],
            'USD' => [
                'flag'   => 'US',
                'symbol' => 'US $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'US Dollar ($)', 'ads' )
            ],
            'ZAR' => [
                'flag'   => 'ZA',
                'symbol' => ' ZAR',
                'pos'    => 'after',
                'title'  => self::getTitle( 'South African Rands (ZAR)', 'ads' )
            ],
            'ANG' => [
                'flag'   => 'AN',
                'symbol' => 'ƒ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Netherlands Antillean Guilder (ANG)', 'ads' )
            ],
            'AOA' => [
                'flag'   => 'AO',
                'symbol' => 'Kz ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Angolan Kwanza (AOA)', 'ads' )
            ],
            'ARS' => [
                'flag'   => 'AR',
                'symbol' => 'ARS $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Argentine Peso (ARS)', 'ads' )
            ],
            'AWG' => [
                'flag'   => 'AW',
                'symbol' => 'Afl. ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Aruban Florin (AWG)', 'ads' )
            ],
            'AZN' => [
                'flag'   => 'AZ',
                'symbol' => 'ман ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Azerbaijani Manat (AZN)', 'ads' )
            ],
            'BAM' => [
                'flag'   => 'BA',
                'symbol' => 'KM ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Bosnia-Herzegovina Convertible Mark (BAM)', 'ads' )
            ],
            'BBD' => [
                'flag'   => 'BB',
                'symbol' => 'BBD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Barbadian Dollar (BBD)', 'ads' )
            ],
            'BGN' => [
                'flag'   => 'BG',
                'symbol' => ' лв',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Bulgarian Lev (BGN)', 'ads' )
            ],
            'BHD' => [
                'flag'   => 'BH',
                'symbol' => 'BD ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Bahraini Dinar (BHD)', 'ads' )
            ],
            'BIF' => [
                'flag'   => 'BI',
                'symbol' => 'FBu ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Burundian Franc (BIF)', 'ads' )
            ],
            'BMD' => [
                'flag'   => 'BM',
                'symbol' => 'BMD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Bermudan Dollar (BMD)', 'ads' )
            ],
            'BND' => [
                'flag'   => 'BN',
                'symbol' => 'B$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Brunei Dollar (BND)', 'ads' )
            ],
            'BOB' => [
                'flag'   => 'BO',
                'symbol' => 'Bs. ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Bolivian Boliviano (BOB)', 'ads' )
            ],
            'BSD' => [
                'flag'   => 'BS',
                'symbol' => 'BSD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Bahamian Dollar (BSD)', 'ads' )
            ],
            'BTN' => [
                'flag'   => 'BT',
                'symbol' => 'Nu. ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Bhutanese Ngultrum (BTN)', 'ads' )
            ],
            'BWP' => [
                'flag'   => 'BW',
                'symbol' => 'P ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Botswanan Pula (BWP)', 'ads' )
            ],
            'BYN' => [
                'flag'   => 'BY',
                'symbol' => ' p.',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Belarusian Ruble (BYN)', 'ads' )
            ],
            'BZD' => [
                'flag'   => 'BZ',
                'symbol' => 'BZD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Belize Dollar (BZD)', 'ads' )
            ],
            'CLF' => [
                'flag'   => 'CL',
                'symbol' => 'UF ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Chilean Unit of Account (UF) (CLF)', 'ads' )
            ],
            'CNH' => [
                'flag'   => 'CN',
                'symbol' => ' CNH',
                'pos'    => 'after',
                'title'  => self::getTitle( 'CNH (CNH)', 'ads' )
            ],
            'CRC' => [
                'flag'   => 'CR',
                'symbol' => '₡ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Costa Rican Colón (CRC)', 'ads' )
            ],
            'CUP' => [
                'flag'   => 'CU',
                'symbol' => '₱ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Cuban Peso (CUP)', 'ads' )
            ],
            'CVE' => [
                'flag'   => 'CV',
                'symbol' => 'CVE $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Cape Verdean Escudo (CVE)', 'ads' )
            ],
            'DJF' => [
                'flag'   => 'DJ',
                'symbol' => ' Fdj',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Djiboutian Franc (DJF)', 'ads' )
            ],
            'DKK' => [
                'flag'   => 'DK',
                'symbol' => 'kr ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Danish Krone (DKK)', 'ads' )
            ],
            'DOP' => [
                'flag'   => 'DO',
                'symbol' => 'RD$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Dominican Peso (DOP)', 'ads' )
            ],
            "EGP" => [
                "flag"   => "EG",
                "symbol" => " EGP",
                "pos"    => "after",
                "title"  => self::getTitle( "Egyptian Pound (EGP)", "ads" )
            ],
            'ERN' => [
                'flag'   => 'ER',
                'symbol' => 'Nfk ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Eritrean Nakfa (ERN)', 'ads' )
            ],
            'ETB' => [
                'flag'   => 'ET',
                'symbol' => 'Br ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Ethiopian Birr (ETB)', 'ads' )
            ],
            'FJD' => [
                'flag'   => 'FJ',
                'symbol' => 'FJD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Fijian Dollar (FJD)', 'ads' )
            ],
            'FKP' => [
                'flag'   => 'FK',
                'symbol' => '‎£ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Falkland Islands Pound (FKP)', 'ads' )
            ],
            'GEL' => [
                'flag'   => 'GE',
                'symbol' => ' GEL',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Georgian Lari (GEL)', 'ads' )
            ],
            "GHS" => [
                "flag"   => "GH",
                "symbol" => "GH₵ ",
                "pos"    => "before",
                "title"  => self::getTitle( "Ghanaian Cedi (GHS)", "ads" )
            ],
            'GIP' => [
                'flag'   => 'GI',
                'symbol' => '£ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Gibraltar Pound (GIP)', 'ads' )
            ],
            'GMD' => [
                'flag'   => 'GM',
                'symbol' => 'D ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Gambian Dalasi (GMD)', 'ads' )
            ],
            'GNF' => [
                'flag'   => 'GN',
                'symbol' => 'FG ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Guinean Franc (GNF)', 'ads' )
            ],
            'GTQ' => [
                'flag'   => 'GT',
                'symbol' => 'Q ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Guatemalan Quetzal (GTQ)', 'ads' )
            ],
            'GYD' => [
                'flag'   => 'GY',
                'symbol' => 'GYD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Guyanaese Dollar (GYD)', 'ads' )
            ],
            'HKD' => [
                'flag'   => 'HK',
                'symbol' => 'HK$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Hong Kong Dollar (HK$)', 'ads' )
            ],
            'HNL' => [
                'flag'   => 'HN',
                'symbol' => 'L ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Honduran Lempira (HNL)', 'ads' )
            ],
            'HTG' => [
                'flag'   => 'HT',
                'symbol' => 'G ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Haitian Gourde (HTG)', 'ads' )
            ],
            'IQD' => [
                'flag'   => 'IQ',
                'symbol' => ' د.ع',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Iraqi Dinar (IQD)', 'ads' )
            ],
            'IRR' => [
                'flag'   => 'IR',
                'symbol' => ' ﷼',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Iranian Rial (IRR)', 'ads' )
            ],
            'ISK' => [
                'flag'   => 'IS',
                'symbol' => 'kr ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Icelandic Króna (ISK)', 'ads' )
            ],
            "JMD" => [
                "flag"   => "JM",
                "symbol" => "J$ ",
                "pos"    => "before",
                "title"  => self::getTitle( "Jamaican Dollar (JMD)", "ads" )
            ],
            'JOD' => [
                'flag'   => 'JO',
                'symbol' => ' JOD',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Jordanian Dinar (JOD)', 'ads' )
            ],
            "JPY" => [
                "flag"   => "JP",
                "symbol" => "¥ ",
                "pos"    => "before",
                "title"  => self::getTitle( "Japanese Yen (¥)", "ads" )
            ],
            'KES' => [
                'flag'   => 'KE',
                'symbol' => 'KSh ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Kenyan Shilling (KES)', 'ads' )
            ],
            'KGS' => [
                'flag'   => 'KG',
                'symbol' => ' сом',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Kyrgystani Som (KGS)', 'ads' )
            ],
            'KHR' => [
                'flag'   => 'KH',
                'symbol' => '៛ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Cambodian Riel (KHR)', 'ads' )
            ],
            'KMF' => [
                'flag'   => 'KM',
                'symbol' => 'CF ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Comorian Franc (KMF)', 'ads' )
            ],
            'KPW' => [
                'flag'   => 'KP',
                'symbol' => '₩ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'North Korean Won (KPW)', 'ads' )
            ],
            'KWD' => [
                'flag'   => 'KW',
                'symbol' => ' ك',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Kuwaiti Dinar (KWD)', 'ads' )
            ],
            'KYD' => [
                'flag'   => 'KY',
                'symbol' => 'KYD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Cayman Islands Dollar (KYD)', 'ads' )
            ],
            'KZT' => [
                'flag'   => 'KZ',
                'symbol' => '‎₸ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Kazakhstani Tenge (KZT)', 'ads' )
            ],
            'LAK' => [
                'flag'   => 'LA',
                'symbol' => '₭ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Laotian Kip (LAK)', 'ads' )
            ],
            'LBP' => [
                'flag'   => 'LB',
                'symbol' => ' ل.ل',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Lebanese Pound (LBP)', 'ads' )
            ],
            'LRD' => [
                'flag'   => 'LR',
                'symbol' => 'LRD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Liberian Dollar (LRD)', 'ads' )
            ],
            'LSL' => [
                'flag'   => 'LS',
                'symbol' => 'M ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Lesotho Loti (LSL)', 'ads' )
            ],
            'LYD' => [
                'flag'   => 'LY',
                'symbol' => 'LD ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Libyan Dinar (LYD)', 'ads' )
            ],
            'MDL' => [
                'flag'   => 'MD',
                'symbol' => ' MDL',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Moldovan Leu (MDL)', 'ads' )
            ],
            'MGA' => [
                'flag'   => 'MG',
                'symbol' => 'Ar ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Malagasy Ariary (MGA)', 'ads' )
            ],
            'MKD' => [
                'flag'   => 'MK',
                'symbol' => 'ден ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Macedonian Denar (MKD)', 'ads' )
            ],
            'MMK' => [
                'flag'   => 'MM',
                'symbol' => 'K ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Myanmar Kyat (MMK)', 'ads' )
            ],
            'MNT' => [
                'flag'   => 'MN',
                'symbol' => '‎₮ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Mongolian Tugrik (MNT)', 'ads' )
            ],
            'MOP' => [
                'flag'   => 'MO',
                'symbol' => 'MOP$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Macanese Pataca (MOP)', 'ads' )
            ],
            'MRO' => [
                'flag'   => 'MR',
                'symbol' => 'UM ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Mauritanian Ouguiya (MRO)', 'ads' )
            ],
            'MUR' => [
                'flag'   => 'MU',
                'symbol' => '₨ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Mauritian Rupee (MUR)', 'ads' )
            ],
            'MVR' => [
                'flag'   => 'MV',
                'symbol' => 'Rf. ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Maldivian Rufiyaa (MVR)', 'ads' )
            ],
            'MWK' => [
                'flag'   => 'MW',
                'symbol' => 'MK ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Malawian Kwacha (MWK)', 'ads' )
            ],
            'MXN' => [
                'flag'   => 'MX',
                'symbol' => 'MX$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Mexican Peso (MX$)', 'ads' )
            ],
            'MZN' => [
                'flag'   => 'MZ',
                'symbol' => 'MT ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Mozambican Metical (MZN)', 'ads' )
            ],
            'NAD' => [
                'flag'   => 'NA',
                'symbol' => 'NAD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Namibian Dollar (NAD)', 'ads' )
            ],
            'NIO' => [
                'flag'   => 'NI',
                'symbol' => 'C$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Nicaraguan Córdoba (NIO)', 'ads' )
            ],
            'NPR' => [
                'flag'   => 'NP',
                'symbol' => '₨ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Nepalese Rupee (NPR)', 'ads' )
            ],
            'PAB' => [
                'flag'   => 'PA',
                'symbol' => 'B/. ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Panamanian Balboa (PAB)', 'ads' )
            ],
            'PEN' => [
                'flag'   => 'PE',
                'symbol' => 'S/. ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Peruvian Nuevo Sol (PEN)', 'ads' )
            ],
            'PGK' => [
                'flag'   => 'PG',
                'symbol' => 'K ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Papua New Guinean Kina (PGK)', 'ads' )
            ],
            'PYG' => [
                'flag'   => 'PY',
                'symbol' => 'Gs ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Paraguayan Guarani (PYG)', 'ads' )
            ],
            'RON' => [
                'flag'   => 'RO',
                'symbol' => 'lei ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Romanian Leu (RON)', 'ads' )
            ],
            'RSD' => [
                'flag'   => 'RS',
                'symbol' => ' RSD',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Serbian Dinar (RSD)', 'ads' )
            ],
            'RWF' => [
                'flag'   => 'RW',
                'symbol' => ' RWF',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Rwandan Franc (RWF)', 'ads' )
            ],
            'SBD' => [
                'flag'   => 'SB',
                'symbol' => 'SI$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Solomon Islands Dollar (SBD)', 'ads' )
            ],
            'SCR' => [
                'flag'   => 'SC',
                'symbol' => 'SR ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Seychellois Rupee (SCR)', 'ads' )
            ],
            'SDG' => [
                'flag'   => 'SD',
                'symbol' => 'SD',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Sudanese Pound (SDG)', 'ads' )
            ],
            'SLL' => [
                'flag'   => 'SL',
                'symbol' => 'Le ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Sierra Leonean Leone (SLL)', 'ads' )
            ],
            'SOS' => [
                'flag'   => 'SO',
                'symbol' => 'S ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Somali Shilling (SOS)', 'ads' )
            ],
            'SRD' => [
                'flag'   => 'SR',
                'symbol' => 'SRD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Surinamese Dollar (SRD)', 'ads' )
            ],
            'STD' => [
                'flag'   => 'ST',
                'symbol' => 'Db ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'São Tomé &amp; Príncipe Dobra (STD)', 'ads' )
            ],
            'SVC' => [
                'flag'   => 'SV',
                'symbol' => '₡ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Salvadoran Colón (SVC)', 'ads' )
            ],
            'SYP' => [
                'flag'   => 'SY',
                'symbol' => '£ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Syrian Pound (SYP)', 'ads' )
            ],
            'SZL' => [
                'flag'   => 'SZ',
                'symbol' => 'E ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Swazi Lilangeni (SZL)', 'ads' )
            ],
            'TJS' => [
                'flag'   => 'TJ',
                'symbol' => ' TJS',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Tajikistani Somoni (TJS)', 'ads' )
            ],
            'TMT' => [
                'flag'   => 'TM',
                'symbol' => 'T ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Turkmenistani Manat (TMT)', 'ads' )
            ],
            'TOP' => [
                'flag'   => 'TO',
                'symbol' => 'T$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Tongan Paʻanga (TOP)', 'ads' )
            ],
            'TRY' => [
                'flag'   => 'TR',
                'symbol' => ' TL',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Turkish Lira (TRY)', 'ads' )
            ],
            'TTD' => [
                'flag'   => 'TT',
                'symbol' => 'TTD $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Trinidad &amp; Tobago Dollar (TTD)', 'ads' )
            ],
            'TWD' => [
                'flag'   => 'TW',
                'symbol' => 'NT$ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'New Taiwan Dollar (NT$)', 'ads' )
            ],
            'TZS' => [
                'flag'   => 'TZ',
                'symbol' => 'TSh ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Tanzanian Shilling (TZS)', 'ads' )
            ],
            'UGX' => [
                'flag'   => 'UG',
                'symbol' => 'USh ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Ugandan Shilling (UGX)', 'ads' )
            ],
            'UYU' => [
                'flag'   => 'UY',
                'symbol' => '$U ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Uruguayan Peso (UYU)', 'ads' )
            ],
            'UZS' => [
                'flag'   => 'UZ',
                'symbol' => " so'm",
                'pos'    => 'after',
                'title'  => self::getTitle( 'Uzbekistani Som (UZS)', 'ads' )
            ],
            'VEF' => [
                'flag'   => 'VE',
                'symbol' => 'Bs. ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Venezuelan Bolívar (VEF)', 'ads' )
            ],
            'VND' => [
                'flag'   => 'VN',
                'symbol' => '₫ ',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Vietnamese Dong (₫)', 'ads' )
            ],
            'VUV' => [
                'flag'   => 'VU',
                'symbol' => ' VT',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Vanuatu Vatu (VUV)', 'ads' )
            ],
            'WST' => [
                'flag'   => 'WS',
                'symbol' => 'WST $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Samoan Tala (WST)', 'ads' )
            ],
            'YER' => [
                'flag'   => 'YE',
                'symbol' => ' ﷼',
                'pos'    => 'after',
                'title'  => self::getTitle( 'Yemeni Rial (YER)', 'ads' )
            ],
            'ZWL' => [
                'flag'   => 'ZW',
                'symbol' => 'ZWL $',
                'pos'    => 'before',
                'title'  => self::getTitle( 'Zimbabwean Dollar (2009) (ZWL)', 'ads' )
            ]
	];

	return $foo;
    }

    /**
     * getTitle
     * 
     * @param type $title
     * @param type $tag
     * @return type
     */
    public static function getTitle($title, $tag)
    {
        return $title;
    }
}