<?php

namespace progress\models\pdo;

/**
 * Description of MysqlPDO
 *
 * @author Artem Yuriev art3mk4@gmail.com Nov 28, 2018 4:00:45 PM
 */
class MysqlPDO extends \PDO
{

    /**
     * LIMIT
     */
    const LIMIT = 20;

    /**
     *
     * @var type 
     */
    public $table;

    /**
     * MysqlPDO constructor
     */
    public function __construct()
    {
        $host = 'mysql:host=' . DB_HOST . ';dbname=' . DB_NAME . ';charset=' . DB_CHARSET;
        parent::__construct($host, DB_USER, DB_PASSWORD);
    }

    /**
     * getTable
     * 
     * @return type
     */
    public function getTable()
    {
        return $this->table;
    }

    /**
     * setTable
     * 
     * @param type $table
     */
    public function setTable($table)
    {
        $this->table = $table;
    }

    /**
     * insert
     * 
     * @param type $arguments
     * @param type $table
     */
    public function insert($arguments = array(), $table = '')
    {
        if (!empty($table)) {
            $this->setTable($table);
        }

        $insertFields = implode(', ', array_keys($arguments));
        $params = implode(', ', array_fill(0, count($arguments), '?'));
        $insert = $this->prepare('INSERT INTO ' . TABLE_PREFIX . $this->table . '(' . $insertFields . ') VALUES (' . $params . ')');
        $insert->execute(array_values($arguments));
    }

    /**
     * update
     * 
     * @param type $arguments
     * @param type $where
     * @param type $table
     */
    public function update($arguments = array(), $where = array(), $table = '')
    {
        if (!empty($table)) {
            $this->setTable($table);
        }

        $updateParams = array();
        foreach ($arguments as $key => $value) {
            $updateParams[] = $key . ' = :' . $key;
        }
        $updateString = implode(', ', $updateParams);

        $whereParams = array();
        foreach ($where as $key => $value) {
            $whereParams[] = $key . ' = :' . $key;
        }
        $whereString = implode('', $whereParams);

        if (!empty($whereString)) {
            $whereString = 'WHERE ' . $whereString;
        }

        $update = $this->prepare('UPDATE ' . TABLE_PREFIX . $this->table . ' SET ' . $updateString . ' ' . $whereString);
        foreach ($arguments as $key => $value) {
            $update->bindValue(':' . $key, $value);
        }

        foreach ($where as $key => $value) {
            $update->bindValue(':' . $key, $value);
        }

        $update->execute();
    }

    /**
     * delete
     * 
     * @param type $arguments
     * @param type $table
     * @return type
     */
    public function delete($arguments = array(), $table = '')
    {
        if (!empty($table)) {
            $this->setTable($table);
        }

        $where = '';
        if (count($arguments) == 1) {
            $key = array_keys($arguments);
            $where = $key[0] . ' = ' . ':' . $key[0];
        } else {
            $where = $this->getWhere($arguments);
        }

        $delete = $this->prepare('DELETE FROM ' . TABLE_PREFIX . $table . ' WHERE ' . $where);
        foreach ($arguments as $field => $value) {
            $delete->bindValue(':' . $field, $value);
        }
        $delete->execute();

        return $delete->rowCount();
    }

    /**
     * find
     * 
     * @param type $arguments
     * @param type $table
     * @return type
     */
    public function find($arguments = array(), $table = '')
    {
        if (!empty($table)) {
            $this->setTable($table);
        }

        $where = '';
        if (!empty($arguments)) {
            $where = $this->getWhere($arguments);
        }

        $select = $this->prepare('SELECT * FROM ' . TABLE_PREFIX . $this->table . ' ' . $where);
        foreach ($arguments as $field => $value) {
            $select->bindValue(':' . $field, $value);
        }

        $select->execute();
        return $select->fetch(\PDO::FETCH_ASSOC);
    }

    /**
     * findAll
     * 
     * @param type $arguments
     * @param type $table
     * @return type
     */
    public function findAll($arguments = array(), $table = '')
    {
        if (!empty($table)) {
            $this->setTable($table);
        }

        $where = '';
        if (!empty($arguments)) {
            $where = $this->getWhere($arguments);
        }

        $select = $this->prepare('SELECT * FROM ' . TABLE_PREFIX . $this->table . ' ' . $where);
        foreach ($arguments as $field => $value) {
            $select->bindValue(':' . $field, $value);
        }

        $select->execute();
        return $select->fetchAll(\PDO::FETCH_ASSOC);
    }

    /**
     * getWhere
     * 
     * @param type $arguments
     * @param type $operand
     * @return type
     */
    public function getWhere($arguments, $operand = ' AND ')
    {
        $whereKeys = array();
        foreach ($arguments as $field => $value) {
            $whereKeys[]= $field . ' = :' . $field; 
        }

        if (!empty($operand)) {
            return 'WHERE ' . implode($operand, $whereKeys);
        }

        return 'WHERE ' . implode('', $whereKeys);
    }
}